unit DebugSupport;

{$ifdef Ver100} { Delphi 3.0x }
  {$define Delphi3}
{$endif}
{$ifdef Ver110} { C++ Builder 3.0x }
  {$define Delphi3}
{$endif}
{$ifdef Ver120} { Delphi 4.0x }
  {$define Delphi4}
{$endif}
{$ifdef Ver125} { C++Builder 4.0x }
  {$define Delphi4}
{$endif}
{$ifdef ConditionalExpressions}
  {$define Delphi6AndAbove}
{$endif}

{$ifdef Delphi3}
  'This unit requires Delphi 4 or later'
{$endif}

interface

procedure DebugMsg(const Msg: String; ShowPIDAndTID: Boolean = False); overload;
procedure DebugMsg(const Msg: String; const Params: array of const;
  ShowPIDAndTID: Boolean = False); overload;

implementation

uses
{$ifdef Delphi6AndAbove}
  Variants,
{$endif}
  SysUtils, Windows;

//This returns the passed message, prepending PID & TID info to it if needed
function MakeDebugMsg(const Msg: String; ShowPIDAndTID: Boolean): String;
begin
  if ShowPIDAndTID then
    Result := Format('PID = %d ($%0:x), TID = %d ($%1:x): %s',
      [GetCurrentProcessID, GetCurrentThreadID, Msg])
  else
    Result := Msg;
end;

procedure InternalDebugMsg(const Msg: String);
begin
  OutputDebugString(PChar(Msg))
end;

procedure DebugMsg(const Msg: String; ShowPIDAndTID: Boolean = False); overload;
begin
  InternalDebugMsg(MakeDebugMsg(Msg, ShowPIDAndTID));
end;

procedure DebugMsg(const Msg: String; const Params: array of const;
  ShowPIDAndTID: Boolean = False); overload;
begin
  DebugMsg(Format(Msg, Params), ShowPIDAndTID)
end;

initialization
  //Ensure these two routines are definitely linked
  //into the EXE, so breakpoints can use them
  TimeToStr(Time);
finalization
end.
